@@ -1,14 +1,14 @@
 /* mpfr_cmp_ui_2exp -- compare a floating-point number with an unsigned
 machine integer multiplied by a power of 2
 
-Copyright 1999, 2001, 2002, 2003, 2004, 2006, 2007, 2008, 2009 Free Software Foundation, Inc.
+Copyright 1999, 2001, 2002, 2003, 2004, 2006, 2007, 2008, 2009, 2010 Free Software Foundation, Inc.
 Contributed by the Arenaire and Cacao projects, INRIA.
 
 This file is part of the GNU MPFR Library.
 
 The GNU MPFR Library is free software; you can redistribute it and/or modify
 it under the terms of the GNU Lesser General Public License as published by
-the Free Software Foundation; either version 2.1 of the License, or (at your
+the Free Software Foundation; either version 3 of the License, or (at your
 option) any later version.
 
 The GNU MPFR Library is distributed in the hope that it will be useful, but
@@ -17,9 +17,9 @@ or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
 License for more details.
 
 You should have received a copy of the GNU Lesser General Public License
-along with the GNU MPFR Library; see the file COPYING.LIB.  If not, write to
-the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
-MA 02110-1301, USA. */
+along with the GNU MPFR Library; see the file COPYING.LESSER.  If not, see
+http://www.gnu.org/licenses/ or write to the Free Software Foundation, Inc.,
+51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA. */
 
 #define MPFR_NEED_LONGLONG_H
 #include "mpfr-impl.h"
@@ -31,7 +31,7 @@ MA 02110-1301, USA. */
 */
 
 int
-mpfr_cmp_ui_2exp (mpfr_srcptr b, unsigned long int i, mp_exp_t f)
+mpfr_cmp_ui_2exp (mpfr_srcptr b, unsigned long int i, mpfr_exp_t f)
 {
   if (MPFR_UNLIKELY( MPFR_IS_SINGULAR(b) ))
     {
@@ -53,7 +53,7 @@ mpfr_cmp_ui_2exp (mpfr_srcptr b, unsigned long int i, mp_exp_t f)
     return 1;
   else /* b > 0, i > 0 */
     {
-      mp_exp_t e;
+      mpfr_exp_t e;
       int k;
       mp_size_t bn;
       mp_limb_t c, *bp;
@@ -64,21 +64,21 @@ mpfr_cmp_ui_2exp (mpfr_srcptr b, unsigned long int i, mp_exp_t f)
       e = MPFR_GET_EXP (b); /* 2^(e-1) <= b < 2^e */
       if (e <= f)
         return -1;
-      if (f < MPFR_EMAX_MAX - BITS_PER_MP_LIMB &&
-          e > f + BITS_PER_MP_LIMB)
+      if (f < MPFR_EMAX_MAX - GMP_NUMB_BITS &&
+          e > f + GMP_NUMB_BITS)
         return 1;
 
-      /* now f < e <= f + BITS_PER_MP_LIMB */
+      /* now f < e <= f + GMP_NUMB_BITS */
       c = (mp_limb_t) i;
       count_leading_zeros(k, c);
-      if ((int) (e - f) > BITS_PER_MP_LIMB - k)
+      if ((int) (e - f) > GMP_NUMB_BITS - k)
         return 1;
-      if ((int) (e - f) < BITS_PER_MP_LIMB - k)
+      if ((int) (e - f) < GMP_NUMB_BITS - k)
         return -1;
 
       /* now b and i*2^f have the same exponent */
       c <<= k;
-      bn = (MPFR_PREC(b) - 1) / BITS_PER_MP_LIMB;
+      bn = (MPFR_PREC(b) - 1) / GMP_NUMB_BITS;
       bp = MPFR_MANT(b);
       if (bp[bn] > c)
         return 1;
