@@ -1,13 +1,13 @@
 /* mpfr_log1p -- Compute log(1+x)
 
-Copyright 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009 Free Software Foundation, Inc.
+Copyright 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010 Free Software Foundation, Inc.
 Contributed by the Arenaire and Cacao projects, INRIA.
 
 This file is part of the GNU MPFR Library.
 
 The GNU MPFR Library is free software; you can redistribute it and/or modify
 it under the terms of the GNU Lesser General Public License as published by
-the Free Software Foundation; either version 2.1 of the License, or (at your
+the Free Software Foundation; either version 3 of the License, or (at your
 option) any later version.
 
 The GNU MPFR Library is distributed in the hope that it will be useful, but
@@ -16,9 +16,9 @@ or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
 License for more details.
 
 You should have received a copy of the GNU Lesser General Public License
-along with the GNU MPFR Library; see the file COPYING.LIB.  If not, write to
-the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
-MA 02110-1301, USA. */
+along with the GNU MPFR Library; see the file COPYING.LESSER.  If not, see
+http://www.gnu.org/licenses/ or write to the Free Software Foundation, Inc.,
+51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA. */
 
 #define MPFR_NEED_LONGLONG_H
 #include "mpfr-impl.h"
@@ -27,10 +27,10 @@ MA 02110-1301, USA. */
     log1p(x)=log(1+x)                      */
 
 int
-mpfr_log1p (mpfr_ptr y, mpfr_srcptr x, mp_rnd_t rnd_mode)
+mpfr_log1p (mpfr_ptr y, mpfr_srcptr x, mpfr_rnd_t rnd_mode)
 {
   int comp, inexact;
-  mp_exp_t ex;
+  mpfr_exp_t ex;
   MPFR_SAVE_EXPO_DECL (expo);
 
   if (MPFR_UNLIKELY (MPFR_IS_SINGULAR (x)))
@@ -97,9 +97,9 @@ mpfr_log1p (mpfr_ptr y, mpfr_srcptr x, mp_rnd_t rnd_mode)
     /* Declaration of the intermediary variable */
     mpfr_t t;
     /* Declaration of the size variable */
-    mp_prec_t Ny = MPFR_PREC(y);             /* target precision */
-    mp_prec_t Nt;                            /* working precision */
-    mp_exp_t err;                            /* error */
+    mpfr_prec_t Ny = MPFR_PREC(y);             /* target precision */
+    mpfr_prec_t Nt;                            /* working precision */
+    mpfr_exp_t err;                            /* error */
     MPFR_ZIV_DECL (loop);
 
     /* compute the precision of intermediary variable */
@@ -119,14 +119,14 @@ mpfr_log1p (mpfr_ptr y, mpfr_srcptr x, mp_rnd_t rnd_mode)
     for (;;)
       {
         /* compute log1p */
-        inexact = mpfr_add_ui (t, x, 1, GMP_RNDN);      /* 1+x */
+        inexact = mpfr_add_ui (t, x, 1, MPFR_RNDN);      /* 1+x */
         /* if inexact = 0, then t = x+1, and the result is simply log(t) */
         if (inexact == 0)
           {
             inexact = mpfr_log (y, t, rnd_mode);
             goto end;
           }
-        mpfr_log (t, t, GMP_RNDN);        /* log(1+x) */
+        mpfr_log (t, t, MPFR_RNDN);        /* log(1+x) */
 
         /* the error is bounded by (1/2+2^(1-EXP(t))*ulp(t) (cf algorithms.tex)
            if EXP(t)>=2, then error <= ulp(t)
