@@ -1,27 +1,25 @@
 /* mpfr_print_binary -- print the internal binary representation of a
                      floating-point number
 
-Copyright 1999, 2000, 2001, 2002, 2003, 2004, 2005 Free Software Foundation, Inc.
+Copyright 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010 Free Software Foundation, Inc.
+Contributed by the Arenaire and Cacao projects, INRIA.
 
-This file is part of the MPFR Library.
+This file is part of the GNU MPFR Library.
 
-The MPFR Library is free software; you can redistribute it and/or modify
+The GNU MPFR Library is free software; you can redistribute it and/or modify
 it under the terms of the GNU Lesser General Public License as published by
-the Free Software Foundation; either version 2.1 of the License, or (at your
+the Free Software Foundation; either version 3 of the License, or (at your
 option) any later version.
 
-The MPFR Library is distributed in the hope that it will be useful, but
+The GNU MPFR Library is distributed in the hope that it will be useful, but
 WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
 License for more details.
 
 You should have received a copy of the GNU Lesser General Public License
-along with the MPFR Library; see the file COPYING.LIB.  If not, write to
-the Free Software Foundation, Inc., 51 Franklin Place, Fifth Floor, Boston,
-MA 02110-1301, USA. */
-
-#include <stdio.h>
-#include <limits.h>
+along with the GNU MPFR Library; see the file COPYING.LESSER.  If not, see
+http://www.gnu.org/licenses/ or write to the Free Software Foundation, Inc.,
+51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA. */
 
 #include "mpfr-impl.h"
 
@@ -44,14 +42,14 @@ mpfr_fprint_binary (FILE *stream, mpfr_srcptr x)
   else
     {
       mp_limb_t *mx;
-      mp_prec_t px;
+      mpfr_prec_t px;
       mp_size_t n;
 
       mx = MPFR_MANT (x);
       px = MPFR_PREC (x);
 
       fprintf (stream, "0.");
-      for (n = (px - 1) / BITS_PER_MP_LIMB; ; n--)
+      for (n = (px - 1) / GMP_NUMB_BITS; ; n--)
         {
           mp_limb_t wd, t;
 
@@ -62,7 +60,7 @@ mpfr_fprint_binary (FILE *stream, mpfr_srcptr x)
               putc ((wd & t) == 0 ? '0' : '1', stream);
               if (--px == 0)
                 {
-                  mp_exp_t ex;
+                  mpfr_exp_t ex;
 
                   ex = MPFR_GET_EXP (x);
                   MPFR_ASSERTN (ex >= LONG_MIN && ex <= LONG_MAX);
@@ -81,17 +79,17 @@ mpfr_print_binary (mpfr_srcptr x)
 }
 
 void
-mpfr_print_mant_binary(const char *str, const mp_limb_t *p, mp_prec_t r)
+mpfr_print_mant_binary(const char *str, const mp_limb_t *p, mpfr_prec_t r)
 {
   int i;
-  mp_prec_t count = 0;
+  mpfr_prec_t count = 0;
   char c;
-  mp_size_t n = (r - 1) / BITS_PER_MP_LIMB + 1;
+  mp_size_t n = (r - 1) / GMP_NUMB_BITS + 1;
 
   printf("%s ", str);
   for(n-- ; n>=0 ; n--)
     {
-      for(i = BITS_PER_MP_LIMB-1 ; i >=0 ; i--)
+      for(i = GMP_NUMB_BITS-1 ; i >=0 ; i--)
         {
           c = (p[n] & (((mp_limb_t)1L)<<i)) ? '1' : '0';
           putchar(c);
@@ -105,17 +103,17 @@ mpfr_print_mant_binary(const char *str, const mp_limb_t *p, mp_prec_t r)
 }
 
 void
-mpfr_dump_mant (const mp_limb_t *p, mp_prec_t r, mp_prec_t precx,
-                mp_prec_t error)
+mpfr_dump_mant (const mp_limb_t *p, mpfr_prec_t r, mpfr_prec_t precx,
+                mpfr_prec_t error)
 {
   int i;
-  mp_prec_t count = 0;
+  mpfr_prec_t count = 0;
   char c;
-  mp_size_t n = (r - 1) / BITS_PER_MP_LIMB + 1;
+  mp_size_t n = (r - 1) / GMP_NUMB_BITS + 1;
 
   for(n-- ; n>=0 ; n--)
     {
-      for(i = BITS_PER_MP_LIMB-1 ; i >=0 ; i--)
+      for(i = GMP_NUMB_BITS-1 ; i >=0 ; i--)
         {
           c = (p[n] & (((mp_limb_t)1L)<<i)) ? '1' : '0';
           putchar(c);
