@@ -1,13 +1,13 @@
 /* Test file for mpfr_ui_div.
 
-Copyright 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009 Free Software Foundation, Inc.
+Copyright 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010 Free Software Foundation, Inc.
 Contributed by the Arenaire and Cacao projects, INRIA.
 
 This file is part of the GNU MPFR Library.
 
 The GNU MPFR Library is free software; you can redistribute it and/or modify
 it under the terms of the GNU Lesser General Public License as published by
-the Free Software Foundation; either version 2.1 of the License, or (at your
+the Free Software Foundation; either version 3 of the License, or (at your
 option) any later version.
 
 The GNU MPFR Library is distributed in the hope that it will be useful, but
@@ -16,9 +16,9 @@ or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
 License for more details.
 
 You should have received a copy of the GNU Lesser General Public License
-along with the GNU MPFR Library; see the file COPYING.LIB.  If not, write to
-the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
-MA 02110-1301, USA. */
+along with the GNU MPFR Library; see the file COPYING.LESSER.  If not, see
+http://www.gnu.org/licenses/ or write to the Free Software Foundation, Inc.,
+51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA. */
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -27,7 +27,7 @@ MA 02110-1301, USA. */
 
 /* checks that y/x gives the right result with 53 bits of precision */
 static void
-check (unsigned long y, const char *xs, mp_rnd_t rnd_mode, const char *zs)
+check (unsigned long y, const char *xs, mpfr_rnd_t rnd_mode, const char *zs)
 {
   mpfr_t xx, zz;
 
@@ -37,7 +37,7 @@ check (unsigned long y, const char *xs, mp_rnd_t rnd_mode, const char *zs)
   if (mpfr_cmp_str1(zz, zs))
     {
       printf ("expected quotient is %s, got ", zs);
-      mpfr_out_str (stdout, 10, 0, zz, GMP_RNDN);
+      mpfr_out_str (stdout, 10, 0, zz, MPFR_RNDN);
       printf ("mpfr_ui_div failed for y=%lu x=%s with rnd_mode=%s\n",
               y, xs, mpfr_print_rnd_mode (rnd_mode));
       exit (1);
@@ -49,7 +49,7 @@ static void
 check_inexact (void)
 {
   mpfr_t x, y, z;
-  mp_prec_t px, py;
+  mpfr_prec_t px, py;
   int inexact, cmp;
   unsigned long int u;
   int rnd;
@@ -71,10 +71,10 @@ check_inexact (void)
         {
           mpfr_set_prec (y, py);
           mpfr_set_prec (z, py + px);
-          for (rnd = 0; rnd < GMP_RND_MAX; rnd++)
+          for (rnd = 0; rnd < MPFR_RND_MAX; rnd++)
             {
-              inexact = mpfr_ui_div (y, u, x, (mp_rnd_t) rnd);
-              if (mpfr_mul (z, y, x, (mp_rnd_t) rnd))
+              inexact = mpfr_ui_div (y, u, x, (mpfr_rnd_t) rnd);
+              if (mpfr_mul (z, y, x, (mpfr_rnd_t) rnd))
                 {
                   printf ("z <- y * x should be exact\n");
                   exit (1);
@@ -85,7 +85,7 @@ check_inexact (void)
                   ((inexact < 0) && (cmp >= 0)))
                 {
                   printf ("Wrong inexact flag for u=%lu, rnd=%s\n",
-                          u, mpfr_print_rnd_mode ((mp_rnd_t) rnd));
+                          u, mpfr_print_rnd_mode ((mpfr_rnd_t) rnd));
                   printf ("expected %d, got %d\n", cmp, inexact);
                   printf ("x="); mpfr_print_binary (x); puts ("");
                   printf ("y="); mpfr_print_binary (y); puts ("");
@@ -110,50 +110,48 @@ check_nan (void)
   mpfr_init2 (q, 100L);
 
   /* 1/+inf == 0 */
-  MPFR_CLEAR_FLAGS (d);
   MPFR_SET_INF (d);
   MPFR_SET_POS (d);
-  MPFR_ASSERTN (mpfr_ui_div (q, 1L, d, GMP_RNDZ) == 0); /* exact */
+  MPFR_ASSERTN (mpfr_ui_div (q, 1L, d, MPFR_RNDZ) == 0); /* exact */
   MPFR_ASSERTN (mpfr_number_p (q));
   MPFR_ASSERTN (mpfr_sgn (q) == 0);
 
   /* 1/-inf == -0 */
-  MPFR_CLEAR_FLAGS (d);
   MPFR_SET_INF (d);
   MPFR_SET_NEG (d);
-  MPFR_ASSERTN (mpfr_ui_div (q, 1L, d, GMP_RNDZ) == 0); /* exact */
+  MPFR_ASSERTN (mpfr_ui_div (q, 1L, d, MPFR_RNDZ) == 0); /* exact */
   MPFR_ASSERTN (mpfr_number_p (q));
   MPFR_ASSERTN (mpfr_sgn (q) == 0);
 
   /* 1/nan == nan */
   MPFR_SET_NAN (d);
-  MPFR_ASSERTN (mpfr_ui_div (q, 1L, d, GMP_RNDZ) == 0); /* exact */
+  MPFR_ASSERTN (mpfr_ui_div (q, 1L, d, MPFR_RNDZ) == 0); /* exact */
   MPFR_ASSERTN (mpfr_nan_p (q));
 
   /* 0/0 == nan */
-  mpfr_set_ui (d, 0L, GMP_RNDN);
-  MPFR_ASSERTN (mpfr_ui_div (q, 0L, d, GMP_RNDZ) == 0); /* exact */
+  mpfr_set_ui (d, 0L, MPFR_RNDN);
+  MPFR_ASSERTN (mpfr_ui_div (q, 0L, d, MPFR_RNDZ) == 0); /* exact */
   MPFR_ASSERTN (mpfr_nan_p (q));
 
   /* 1/+0 = +inf */
-  mpfr_set_ui (d, 0L, GMP_RNDN);
-  MPFR_ASSERTN (mpfr_ui_div (q, 1L, d, GMP_RNDZ) == 0); /* exact */
+  mpfr_set_ui (d, 0L, MPFR_RNDN);
+  MPFR_ASSERTN (mpfr_ui_div (q, 1L, d, MPFR_RNDZ) == 0); /* exact */
   MPFR_ASSERTN (mpfr_inf_p (q) && mpfr_sgn (q) > 0);
 
   /* 1/-0 = -inf */
-  mpfr_set_ui (d, 0L, GMP_RNDN);
-  mpfr_neg (d, d, GMP_RNDN);
-  MPFR_ASSERTN (mpfr_ui_div (q, 1L, d, GMP_RNDZ) == 0); /* exact */
+  mpfr_set_ui (d, 0L, MPFR_RNDN);
+  mpfr_neg (d, d, MPFR_RNDN);
+  MPFR_ASSERTN (mpfr_ui_div (q, 1L, d, MPFR_RNDZ) == 0); /* exact */
   MPFR_ASSERTN (mpfr_inf_p (q) && mpfr_sgn (q) < 0);
 
   /* 0/1 = +0 */
-  mpfr_set_ui (d, 1L, GMP_RNDN);
-  MPFR_ASSERTN (mpfr_ui_div (q, 0L, d, GMP_RNDZ) == 0); /* exact */
+  mpfr_set_ui (d, 1L, MPFR_RNDN);
+  MPFR_ASSERTN (mpfr_ui_div (q, 0L, d, MPFR_RNDZ) == 0); /* exact */
   MPFR_ASSERTN (mpfr_cmp_ui (q, 0) == 0 && MPFR_IS_POS (q));
 
   /* 0/-1 = -0 */
-  mpfr_set_si (d, -1, GMP_RNDN);
-  MPFR_ASSERTN (mpfr_ui_div (q, 0L, d, GMP_RNDZ) == 0); /* exact */
+  mpfr_set_si (d, -1, MPFR_RNDN);
+  MPFR_ASSERTN (mpfr_ui_div (q, 0L, d, MPFR_RNDZ) == 0); /* exact */
   MPFR_ASSERTN (mpfr_cmp_ui (q, 0) == 0 && MPFR_IS_NEG (q));
 
   mpfr_clear (d);
@@ -161,7 +159,7 @@ check_nan (void)
 }
 
 static int
-mpfr_inv (mpfr_ptr y, mpfr_srcptr x, mp_rnd_t r)
+mpfr_inv (mpfr_ptr y, mpfr_srcptr x, mpfr_rnd_t r)
 {
   return mpfr_ui_div (y, 1, x, r);
 }
@@ -173,15 +171,15 @@ main (int argc, char *argv[])
 
   check_nan ();
   check_inexact ();
-  check(948002822, "1.22191250737771397120e+20", GMP_RNDN,
+  check(948002822, "1.22191250737771397120e+20", MPFR_RNDN,
         "7.758352715731357946e-12");
-  check(1976245324, "1.25296395864546893357e+232", GMP_RNDZ,
+  check(1976245324, "1.25296395864546893357e+232", MPFR_RNDZ,
         "1.5772563211925444801e-223");
-  check(740454110, "2.11496253355831863313e+183", GMP_RNDZ,
+  check(740454110, "2.11496253355831863313e+183", MPFR_RNDZ,
         "3.5010270784996976041e-175");
-  check(1690540942, "1.28278599852446657468e-276", GMP_RNDU,
+  check(1690540942, "1.28278599852446657468e-276", MPFR_RNDU,
         "1.3178666932321966062e285");
-  check(1476599377, "-2.14191393656148625995e+305", GMP_RNDD,
+  check(1476599377, "-2.14191393656148625995e+305", MPFR_RNDD,
         "-6.8938315017943889615e-297");
 
   /* inv is for 1/x */
